<p class="logo">
  <a href="{{ pathto(master_doc) }}">
    <img class="logo" src="{{ pathto('_static/eve-sidebar.png', 1) }}" alt="Eve logo"/>
  </a>
</p>
<p>
  <iframe src="http://ghbtns.com/github-btn.html?user=nicolaiarocci&repo=eve&type=watch&count=true&size=large"
    allowtransparency="true" frameborder="0" scrolling="0" width="200px" height="35px"></iframe>
</p> 
<p>
  You are looking at the documentation of the development version.
</p>
<h3>Support Eve</h3>
<p>If you use Eve please consider financial support:</p>
<p>
<a href="https://gum.co/EhzI" class="gumroad-button">Support Eve</a> <script type="text/javascript" src="https://gumroad.com/js/gumroad.js"></script>
</p>
<h3>Get Updates</h3>
<p>Receive updates on new releases and upcoming projects.</p>
<p>
<a href="http://tinyletter.com/nicolaiarocci">Subscribe to Newsletter</a>
</p>
<h3>Useful Links</h3>
<ul>
  <li><a href="http://stackoverflow.com/questions/tagged/eve">Stack Overflow</a></li>
  <li><a href="https://groups.google.com/forum/#!forum/python-eve">Mailing List</a></li>
  <li><a href="http://github.com/nicolaiarocci/eve/issues">Issue Tracker</a></li>
  <li><a href="http://github.com/nicolaiarocci/eve">GitHub</a></li>
  <li><a href="http://blog.python-eve.org/">Blog</a></li>
  <li><a href="http://github.com/nicolaiarocci/eve-demo">Demo</a></li>
  <li><a href="irc://irc.freenode.net/python-eve">IRC</a>
</ul>
<h3>Feedback</h3>
<p>
  Feedback is greatly appreciated. If you have any questions, comments,
  random praise, or anonymous threats, get on the <a href="https://groups.google.com/forum/#!forum/python-eve">mailing list</a> or <a href="mailto:eve@nicolaiarocci.com">
  shoot an email</a>.
</p>
<h3>Powered By</h3>
<ul>
  <li><a href="http://flask.pocoo.org/">Flask</a></li>
  <!--<li><a href="https://github.com/dcrosta/flask-pymongo">Flask-PyMongo</a></li>-->
  <li><a href="http://mongodb.org">MongoDB</a></li>
  <!--<li><a href="https://github.com/mongodb/mongo-python-driver">PyMongo</a></li>-->
  <li><a href="http://github.com/nicolaiarocci/cerberus">Cerberus</a></li>
  <li><a href="http://github.com/nicolaiarocci/events">Events</a></li>
</ul>
